/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <activemq/connector/openwire/marshal/v2/BrokerInfoMarshaller.h>

#include <activemq/connector/openwire/commands/BrokerInfo.h>

//
//     NOTE!: This file is autogenerated - do not modify!
//            if you need to make a change, please see the Java Classes in the
//            activemq-core module
//

using namespace std;
using namespace activemq;
using namespace activemq::io;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;
using namespace activemq::connector::openwire::marshal;
using namespace activemq::connector::openwire::util;
using namespace activemq::connector::openwire::marshal::v2;

///////////////////////////////////////////////////////////////////////////////
DataStructure* BrokerInfoMarshaller::createObject() const {
    return new BrokerInfo();
}

///////////////////////////////////////////////////////////////////////////////
unsigned char BrokerInfoMarshaller::getDataStructureType() const {
    return BrokerInfo::ID_BROKERINFO;
}

///////////////////////////////////////////////////////////////////////////////
void BrokerInfoMarshaller::tightUnmarshal( OpenWireFormat* wireFormat, DataStructure* dataStructure, DataInputStream* dataIn, BooleanStream* bs ) {
   BaseCommandMarshaller::tightUnmarshal( wireFormat, dataStructure, dataIn, bs );

    BrokerInfo* info =
        dynamic_cast<BrokerInfo*>( dataStructure );
    info->setBrokerId( dynamic_cast< BrokerId* >(
        tightUnmarsalCachedObject( wireFormat, dataIn, bs ) );
    info->setBrokerURL( TightUnmarshalString( dataIn, bs ) );

    if( bs->readBoolean() ) {
        short size = dataIn->readShort();
        BrokerInfo* value = new BrokerInfo[size];
        for( int i = 0; i < size; i++ ) {
            value[i] = dynamic_cast< BrokerInfo* >(
                tightUnmarsalNestedObject( wireFormat, dataIn, bs ) );
        }
        info->setPeerBrokerInfos( value );
    }
    else {
        info->setPeerBrokerInfos( NULL );
    }
    info->setBrokerName( TightUnmarshalString( dataIn, bs ) );
    info->setSlaveBroker( bs->readBoolean() );
    info->setMasterBroker( bs->readBoolean() );
    info->setFaultTolerantConfiguration( bs->readBoolean() );
}

///////////////////////////////////////////////////////////////////////////////
int BrokerInfoMarshaller::tightMarshal1( OpenWireFormat& wireFormat, DataStructure* dataStructure, BooleanStream& bs ) {

    BrokerInfo* info =
        dynamic_cast<BrokerInfo*>( dataStructure );

    int rc = BaseCommandMarshaller::tightMarshal1( wireFormat, dataStructure, bs );
    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getBrokerId() );

    rc += tightMarshalCachedObject1( wireFormat, data, bs );
    rc += tightMarshalString1( info->getBrokerURL(), bs );
    rc += tightMarshalObjectArray1( wireFormat, info->getPeerBrokerInfos(), bs );
    rc += tightMarshalString1( info->getBrokerName(), bs );
    bs->writeBoolean( info->isSlaveBroker() );
    bs->writeBoolean( info->isMasterBroker() );
    bs->writeBoolean( info->isFaultTolerantConfiguration() );

    return rc + 0;
}

///////////////////////////////////////////////////////////////////////////////
void BrokerInfoMarshaller::tightMarshal2( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataOutputStream& dataOut, BooleanStream& bs ) {

    BaseCommandMarshaller::tightMarshal2( wireFormat, dataStructure, dataOut, bs );

    BrokerInfo* info =
        dynamic_cast<BrokerInfo*>( dataStructure );
    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getBrokerId() );

    tightMarshalCachedObject2( wireFormat, data, dataOut, bs );
    tightMarshalString2( info->getBrokerURL(), dataOut, bs );
    tightMarshalObjectArray2( wireFormat, info->getPeerBrokerInfos(), dataOut, bs );
    tightMarshalString2( info->getBrokerName(), dataOut, bs );
    bs->readBoolean();
    bs->readBoolean();
    bs->readBoolean();
}

///////////////////////////////////////////////////////////////////////////////
void BrokerInfoMarshaller::looseUnmarshal( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataInputStream& dataIn ) {
    BaseCommandMarshaller::looseUnmarshal( wireFormat, dataStructure, dataIn );
    BrokerInfo* info = 
        dynamic_cast<BrokerInfo*>( dataStructure );
   info->setBrokerId( dynamic_cast<BrokerId* >( 
       looseUnmarshalCachedObject( wireFormat, dataIn ) ) );
    info->setBrokerURL( looseUnmarshalString( dataIn ) );

    if( dataIn->readBoolean() ) {
        short size = dataIn->readShort();
        BrokerInfo* value = new BrokerInfo[size];
        for( int i = 0; i < size; i++ ) {
            value[i] = dynamic_cast<BrokerInfo* >(
                looseUnmarshalNestedObject( wireFormat,dataIn ) );
        }
        info->setPeerBrokerInfos( value );
    }
    else {
        info->setPeerBrokerInfos( NULL );
    }
    info->setBrokerName( looseUnmarshalString( dataIn ) );
    info->setSlaveBroker( dataIn->readBoolean() );
    info->setMasterBroker( dataIn->readBoolean() );
    info->setFaultTolerantConfiguration( dataIn->readBoolean() );
}

///////////////////////////////////////////////////////////////////////////////
void BrokerInfoMarshaller::looseMarshal( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataOutputStream& dataOut ) {
    BrokerInfo* info =
        dynamic_cast<BrokerInfo*>( dataStructure );
    BaseCommandMarshaller::looseMarshal( wireFormat, dataStructure, dataOut );

    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getBrokerId() );

    looseMarshalCachedObject( wireFormat, data, dataOut );
    looseMarshalString( info->getBrokerURL(), dataOut );
    looseMarshalObjectArray( wireFormat, info->getPeerBrokerInfos(), dataOut );
    looseMarshalString( info->getBrokerName(), dataOut );
    dataOut->write( info->isSlaveBroker() );
    dataOut->write( info->isMasterBroker() );
    dataOut->write( info->isFaultTolerantConfiguration() );
}

