/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <activemq/connector/openwire/marshal/v2/ConnectionInfoMarshaller.h>

#include <activemq/connector/openwire/commands/ConnectionInfo.h>

//
//     NOTE!: This file is autogenerated - do not modify!
//            if you need to make a change, please see the Java Classes in the
//            activemq-core module
//

using namespace std;
using namespace activemq;
using namespace activemq::io;
using namespace activemq::connector;
using namespace activemq::connector::openwire;
using namespace activemq::connector::openwire::commands;
using namespace activemq::connector::openwire::marshal;
using namespace activemq::connector::openwire::util;
using namespace activemq::connector::openwire::marshal::v2;

///////////////////////////////////////////////////////////////////////////////
DataStructure* ConnectionInfoMarshaller::createObject() const {
    return new ConnectionInfo();
}

///////////////////////////////////////////////////////////////////////////////
unsigned char ConnectionInfoMarshaller::getDataStructureType() const {
    return ConnectionInfo::ID_CONNECTIONINFO;
}

///////////////////////////////////////////////////////////////////////////////
void ConnectionInfoMarshaller::tightUnmarshal( OpenWireFormat* wireFormat, DataStructure* dataStructure, DataInputStream* dataIn, BooleanStream* bs ) {
   BaseCommandMarshaller::tightUnmarshal( wireFormat, dataStructure, dataIn, bs );

    ConnectionInfo* info =
        dynamic_cast<ConnectionInfo*>( dataStructure );
    info->setConnectionId( dynamic_cast< ConnectionId* >(
        tightUnmarsalCachedObject( wireFormat, dataIn, bs ) );
    info->setClientId( TightUnmarshalString( dataIn, bs ) );
    info->setPassword( TightUnmarshalString( dataIn, bs ) );
    info->setUserName( TightUnmarshalString( dataIn, bs ) );

    if( bs->readBoolean() ) {
        short size = dataIn->readShort();
        BrokerId* value = new BrokerId[size];
        for( int i = 0; i < size; i++ ) {
            value[i] = dynamic_cast< BrokerId* >(
                tightUnmarsalNestedObject( wireFormat, dataIn, bs ) );
        }
        info->setBrokerPath( value );
    }
    else {
        info->setBrokerPath( NULL );
    }
    info->setBrokerMasterConnector( bs->readBoolean() );
    info->setManageable( bs->readBoolean() );
}

///////////////////////////////////////////////////////////////////////////////
int ConnectionInfoMarshaller::tightMarshal1( OpenWireFormat& wireFormat, DataStructure* dataStructure, BooleanStream& bs ) {

    ConnectionInfo* info =
        dynamic_cast<ConnectionInfo*>( dataStructure );

    int rc = BaseCommandMarshaller::tightMarshal1( wireFormat, dataStructure, bs );
    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getConnectionId() );

    rc += tightMarshalCachedObject1( wireFormat, data, bs );
    rc += tightMarshalString1( info->getClientId(), bs );
    rc += tightMarshalString1( info->getPassword(), bs );
    rc += tightMarshalString1( info->getUserName(), bs );
    rc += tightMarshalObjectArray1( wireFormat, info->getBrokerPath(), bs );
    bs->writeBoolean( info->isBrokerMasterConnector() );
    bs->writeBoolean( info->isManageable() );

    return rc + 0;
}

///////////////////////////////////////////////////////////////////////////////
void ConnectionInfoMarshaller::tightMarshal2( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataOutputStream& dataOut, BooleanStream& bs ) {

    BaseCommandMarshaller::tightMarshal2( wireFormat, dataStructure, dataOut, bs );

    ConnectionInfo* info =
        dynamic_cast<ConnectionInfo*>( dataStructure );
    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getConnectionId() );

    tightMarshalCachedObject2( wireFormat, data, dataOut, bs );
    tightMarshalString2( info->getClientId(), dataOut, bs );
    tightMarshalString2( info->getPassword(), dataOut, bs );
    tightMarshalString2( info->getUserName(), dataOut, bs );
    tightMarshalObjectArray2( wireFormat, info->getBrokerPath(), dataOut, bs );
    bs->readBoolean();
    bs->readBoolean();
}

///////////////////////////////////////////////////////////////////////////////
void ConnectionInfoMarshaller::looseUnmarshal( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataInputStream& dataIn ) {
    BaseCommandMarshaller::looseUnmarshal( wireFormat, dataStructure, dataIn );
    ConnectionInfo* info = 
        dynamic_cast<ConnectionInfo*>( dataStructure );
   info->setConnectionId( dynamic_cast<ConnectionId* >( 
       looseUnmarshalCachedObject( wireFormat, dataIn ) ) );
    info->setClientId( looseUnmarshalString( dataIn ) );
    info->setPassword( looseUnmarshalString( dataIn ) );
    info->setUserName( looseUnmarshalString( dataIn ) );

    if( dataIn->readBoolean() ) {
        short size = dataIn->readShort();
        BrokerId* value = new BrokerId[size];
        for( int i = 0; i < size; i++ ) {
            value[i] = dynamic_cast<BrokerId* >(
                looseUnmarshalNestedObject( wireFormat,dataIn ) );
        }
        info->setBrokerPath( value );
    }
    else {
        info->setBrokerPath( NULL );
    }
    info->setBrokerMasterConnector( dataIn->readBoolean() );
    info->setManageable( dataIn->readBoolean() );
}

///////////////////////////////////////////////////////////////////////////////
void ConnectionInfoMarshaller::looseMarshal( OpenWireFormat& wireFormat, DataStructure* dataStructure, DataOutputStream& dataOut ) {
    ConnectionInfo* info =
        dynamic_cast<ConnectionInfo*>( dataStructure );
    BaseCommandMarshaller::looseMarshal( wireFormat, dataStructure, dataOut );

    DataStructure* data = 
        dynamic_cast< DataStructure* >( info->getConnectionId() );

    looseMarshalCachedObject( wireFormat, data, dataOut );
    looseMarshalString( info->getClientId(), dataOut );
    looseMarshalString( info->getPassword(), dataOut );
    looseMarshalString( info->getUserName(), dataOut );
    looseMarshalObjectArray( wireFormat, info->getBrokerPath(), dataOut );
    dataOut->write( info->isBrokerMasterConnector() );
    dataOut->write( info->isManageable() );
}

